==> ltb-project-service-desk-0.6.2.tar.gz: ltb-project-service-desk-0.6.2/lang/fr.inc.php <==
<?php

#==============================================================================
# French
#==============================================================================

$messages['accountenabled'] = "Le compte est activé";
$messages['accountdisabled'] = "Le compte est désactivé";
$messages['auditlogs'] = "Audit";
$messages['auditlogtitle'] = "Traces d'audit pour les $audit_log_days derniers jours";
$messages['accountlocked'] = "Le compte est verrouillé";
$messages['accountnotdisabled'] = "Échec de la désactivation du compte";
$messages['accountnotenabled'] = "Échec de l'activation du compte";
$messages['accountnotlocked'] = "Échec de verrouillage du compte";
$messages['accountnotunlocked'] = "Échec de déverrouillage du compte";
$messages['accountnotvalid'] = "Le compte n'est pas valide";
$messages['accountstatus'] = "Statut du compte";
$messages['accountunlocked'] = "Le compte n'est pas verrouillé";
$messages['accountvalid'] = "Le compte est valide";
$messages['actionforbidden'] = "Action interdite";
$messages['changesubject'] = "Votre mot de passe a été changé";
$messages['changesubjectforadmin'] = "Le mot de passe d'un utilisateur a été changé";
$messages['changemessage'] = "Bonjour {name},\n\nVotre mot de passe a été changé.\nSi vous n'êtes pas à l'origine de cette demande, contactez votre administrateur pour obtenir des précisions.";
$messages['changemessageforadmin'] = "Bonjour,\n\nLe mot de passe du compte {dn} a été changé.";
$messages['checkpassword'] = "Vérification du mot de passe";
$messages['close'] = "Fermer";
$messages['comment_needed'] = "Un commentaire sera demandé";
$messages['currentpassword'] = "Mot de passe actuel";
$messages['dashboards'] = "Tableaux de bord";
$messages['disableaccount'] = "Désactiver le compte";
$messages['disabledaccounts'] = "Comptes désactivés";
$messages['displayentry'] = "Afficher l'entrée";
$messages['dnrequired'] = "L'identifiant de l'entrée est requis";
$messages['editentry'] = "Modifier l'entrée";
$messages['enableaccount'] = "Activer le compte";
$messages['enddate'] = "Date de fin";
$messages['entriesfound'] = "entrées trouvées";
$messages['entryfound'] = "entrée trouvée";
$messages['eventfound'] = "événement trouvé";
$messages['eventsfound'] = "événements trouvés";
$messages['expiredaccounts'] = "Mots de passe expirés";
$messages['false'] = "Non";
$messages['forcereset'] = "Forcer la réinitialisation à la prochaine connexion";
$messages['hookerror'] = "Une erreur s'est produite dans le hook";
$messages['idleaccounts'] = "Comptes inactifs";
$messages['idleaccountstitle'] = "Comptes inactifs depuis plus de $idledays jours";
$messages['insert_comment'] = "Insérer un commentaire";
$messages['invalidaccounts'] = "Comptes invalides";
$messages['invalidaccountstitle'] = "Comptes invalides";
$messages['pager_all'] = "Tout";
$messages['print_all'] = "Imprimer tous les résultats";
$messages['print_page'] = "Imprimer cette page";
$messages['label_action'] = "Action";
$messages['label_authtimestamp'] = "Dernière authentification";
$messages['label_businesscategory'] = "Catégorie";
$messages['label_carlicense'] = "Permis de conduire";
$messages['label_comment'] = "Commentaire";
$messages["label_created"] = "Créé";
$messages['label_date'] = "Date";
$messages['label_description'] = "Description";
$messages['label_displayname'] = "Nom d'affichage";
$messages['label_done_by'] = "Fait par";
$messages['label_employeenumber'] = "Numéro d'employé";
$messages['label_employeetype'] = "Type d'employé";
$messages['label_endtime'] = "Fin de validité";
$messages['label_expirationdate'] = "Date d'expiration";
$messages['label_fax'] = "Télécopie";
$messages['label_firstname'] = "Prénom";
$messages['label_fullname'] = "Nom complet";
$messages['label_identifier'] = "Identifiant";
$messages['label_ip'] = "Adresse IP";
$messages['label_l'] = "Ville";
$messages['label_lastname'] = "Nom";
$messages['label_mail'] = "Courriel";
$messages['label_mailquota'] = "Quota messagerie";
$messages['label_manager'] = "Responsable";
$messages['label_mobile'] = "Portable";
$messages["label_modified"] = "Modifié";
$messages['label_organization'] = "Organisation";
$messages['label_organizationalunit'] = "Service";
$messages['label_pager'] = "Messagerie";
$messages['label_phone'] = "Téléphone";
$messages['label_postaladdress'] = "Adresse";
$messages['label_postalcode'] = "Code postal";
$messages['label_pwdaccountlockedtime'] = "Date de verrouillage";
$messages['label_pwdchangedtime'] = "Dernier changement de mot de passe";
$messages['label_pwdfailuretime'] = "Derniers échecs d'authentification";
$messages['label_pwdgraceusetime'] = "Dernières authentifications en grâce";
$messages['label_pwdlastsuccess'] = $messages['label_authtimestamp'];
$messages['label_pwdpolicysubentry'] = "Politique des mots de passe associée";
$messages['label_pwdreset'] = "Réinitialisation du mot de passe à la prochaine connexion";
$messages['label_result'] = "Résultat";
$messages['label_secretary'] = "Secrétaire";
$messages['label_starttime'] = "Début de validité";
$messages['label_state'] = "État";
$messages['label_street'] = "Voie";
$messages['label_title'] = "Titre";
$messages['label_user_dn'] = "Utilisateur";
$messages['ldaperror'] = "Erreur de communication avec l'annuaire LDAP";
$messages['lockaccount'] = "Verrouiller le compte";
$messages['lockedaccounts'] = "Comptes verrouillés";
$messages['logout'] = "Déconnexion";
$messages['newpassword'] = "Nouveau mot de passe";
$messages['noentriesfound'] = "Aucune entrée trouvée";
$messages['noeventsfound'] = "Aucun événement trouvé";
$messages['notdefined'] = "Non renseigné";
$messages['password'] = "Mot de passe";
$messages['passwordchanged'] = "Le mot de passe a été changé";
$messages['passwordexpired'] = "Le mot de passe est expiré";
$messages['passwordinvalid'] = "Authentification en échec";
$messages['passwordok'] = "Authentification réussie !";
$messages['passwordrefused'] = "Le mot de passe a été refusé";
$messages['passwordinhistory'] = "Mot de passe déjà dans l'historique";
$messages['passwordrequired'] = "Merci de saisir le mot de passe";
$messages['resetpassword'] = "Réinitialisation du mot de passe";
$messages['search'] = "Rechercher";
$messages['searchrequired'] = "Veuillez saisir votre recherche";
$messages['sizelimit'] = "La limite de recherche a été atteinte, certaines entrées n'ont pas pu être affichées";
$messages['startdate'] = "Date de début";
$messages['submit'] = "Envoyer";
$messages['title'] = "Guichet de service";
$messages['title_search'] = "Résultats de la recherche :";
$messages['tooltip_emailto'] = "Envoyer un email";
$messages['tooltip_phoneto'] = "Composer ce numéro";
$messages['true'] = "Oui";
$messages['unlockaccount'] = "Déverrouiller le compte";
$messages['unlockdate'] = "Date de déblocage automatique :";
$messages['welcome'] = "Bienvenue sur le guichet de service LDAP Tool Box";
$messages['willexpireaccounts'] = "Mots de passe bientôt expirés";
$messages['willexpireaccountstitle'] = "Mots de passe allant expirer dans moins de $willexpiredays jours";
$messages['notcomplex'] = "Votre mot de passe n'a pas assez de classes de caractères différentes.";
$messages['tooshort'] = "Votre mot de passe est trop court";
$messages['toobig'] = "Votre mot de passe est trop long";
$messages['minlower'] = "Votre mot de passe n'a pas assez de minuscules";
$messages['policyminlower'] = "Nombre minimum de minuscules :";
$messages['minupper'] = "Votre mot de passe n'a pas assez de majuscules";
$messages['policyminupper'] = "Nombre minimum de majuscules :";
$messages['mindigit'] = "Votre mot de passe n'a pas assez de chiffres";
$messages['policymindigit'] = "Nombre minimum de chiffres :";
$messages['minspecial'] = "Votre mot de passe n'a pas assez de caractères spéciaux";
$messages['policyminspecial'] = "Nombre minimum de caractères spéciaux :";
$messages['forbiddenchars'] = "Votre mot de passe contient des caractères interdits";
$messages['policyforbiddenchars'] = "Caractères interdits :";
$messages['specialatends'] = "Votre nouveau mot de passe a son unique caractère spécial en première ou dernière position";
$messages['policyspecialatends'] = "Votre nouveau mot de passe ne doit pas avoir son seul caractère spécial en première ou dernière position.";
$messages['sameasold'] = "Votre mot de passe est identique au précédent";
$messages['sameaslogin'] = "Votre mot de passe est identique à votre identifiant";
$messages['policydiffminchars'] = "Nombre de nouveaux caractères unique :";
$messages['diffminchars'] = "Votre nouveau mot de passe est trop similaire au précédant";
$messages['forbiddenwords'] = "Votre mot de passe contient des mots interdits";
$messages['policyforbiddenwords'] = "Votre mot de passe ne doit pas contenir ::";
$messages['forbiddenldapfields'] = "Votre mot de passe contient des valeurs de votre entrée LDAP";
$messages['policyforbiddenldapfields'] = "Votre mot de passe ne doit pas contenir la valeur des attributs de votre entrée :";
$messages['sameascustompwd'] = "Le nouveau mot de passe n'est pas unique par rapport aux autres champs de mots de passe personnalisés";
$messages['pwned'] = "Votre nouveau mot de passe est compromis, vous devriez le changer partout où vous l'utilisez";
$messages['policypwned'] = "Votre nouveau mot de passe ne doit pas être connu d'une base publique de mots de passe compromis";
$messages['insufficiententropy'] = "Entropie insuffisante pour le nouveau mot de passe";
$messages['policy'] = "Votre mot de passe doit respecter les contraintes suivantes :";
$messages['policyminlength'] = "Nombre minimum de caractères :";
$messages['policymaxlength'] = "Nombre maximum de caractères :";
$messages['policyminlower'] = "Nombre minimum de minuscules :";
$messages['policyminupper'] = "Nombre minimum de majuscules :";
$messages['policymindigit'] = "Nombre minimum de chiffres :";
$messages['policyminspecial'] = "Nombre minimum de caractères spéciaux :";
$messages['policycomplex'] = "Nombre minimum de classes de caractères :";
$messages['policyforbiddenchars'] = "Caractères interdits :";
$messages['policydiffminchars'] = "Nombre de nouveaux caractères unique :";
$messages['policynoreuse'] = "Votre nouveau mot de passe ne doit pas être identique à l'ancien";
$messages['policynoreusecustompwdfield'] = "Votre nouveau mot de passe ne devrait pas être le même que le mot de passe de connexion";
$messages['policydifflogin'] = "Votre nouveau mot de passe ne doit pas être identique à votre identifiant";
$messages['policypwned'] = "Votre nouveau mot de passe ne doit pas être connu d'une base publique de mots de passe compromis";
$messages['policyspecialatends'] = "Votre nouveau mot de passe ne doit pas avoir son seul caractère spécial en première ou dernière position.";
$messages['policyentropy'] = "Force du mot de passe";
$messages['updatevaliditydates'] = "Modifier les dates de validité";
$messages['validitydatesnotupdated'] = "Erreur lors de la mise à jour des dates de validité";
$messages['validitydatesupdated'] = "Dates de validité mises à jour";

?>

==> ltb-project-service-desk-0.8.tar.gz: ltb-project-service-desk-0.8/lang/fr.inc.php <==
<?php

#==============================================================================
# French
#==============================================================================

$messages['accountdisabled'] = "Le compte est désactivé";
$messages['accountenabled'] = "Le compte est activé";
$messages['accountlocked'] = "Le compte est verrouillé";
$messages['accountnotdisabled'] = "Échec de la désactivation du compte";
$messages['accountnotenabled'] = "Échec de l'activation du compte";
$messages['accountnotlocked'] = "Échec de verrouillage du compte";
$messages['accountnotunlocked'] = "Échec de déverrouillage du compte";
$messages['accountnotvalid'] = "Le compte n'est pas valide";
$messages['accountstatus'] = "Statut du compte";
$messages['accountunlocked'] = "Le compte n'est pas verrouillé";
$messages['accountvalid'] = "Le compte est valide";
$messages['actionforbidden'] = "Action interdite";
$messages['allaccounts'] = "Liste de tous les comptes";
$messages['auditlogs'] = "Audit";
$messages['auditlogtitle'] = "Traces d'audit pour les $audit_log_days derniers jours";
$messages['cancelbacktoentry'] = "Annuler et revenir à l'entrée";
$messages['changemessage'] = "Bonjour {name},\n\nVotre mot de passe a été changé.\nSi vous n'êtes pas à l'origine de cette demande, contactez votre administrateur pour obtenir des précisions.";
$messages['changemessageforadmin'] = "Bonjour,\n\nLe mot de passe du compte {dn} a été changé.";
$messages['changesubjectforadmin'] = "Le mot de passe d'un utilisateur a été changé";
$messages['changesubject'] = "Votre mot de passe a été changé";
$messages['checkpassword'] = "Vérification du mot de passe";
$messages['close'] = "Fermer";
$messages['comment_needed'] = "Un commentaire sera demandé";
$messages['createentry'] = "Créer une entrée";
$messages['createfailed'] = "La création a échoué";
$messages['createok'] = "L'entrée a été créée";
$messages['currentpassword'] = "Mot de passe actuel";
$messages['dashboards'] = "Tableaux de bord";
$messages['deleteconfirmation'] = "Êtes-vous sûr de vouloir supprimer cette entrée ?";
$messages['deleteentry'] = "Supprimer";
$messages['deletefailed'] = "La suppression a échoué";
$messages['deleteok'] = "L'entrée a été supprimée";
$messages['diffminchars'] = "Votre nouveau mot de passe est trop similaire au précédant";
$messages['disableaccount'] = "Désactiver le compte";
$messages['disabledaccounts'] = "Comptes désactivés";
$messages['displayentry'] = "Afficher l'entrée";
$messages['dnrequired'] = "L'identifiant de l'entrée est requis";
$messages['editentry'] = "Modifier";
$messages['enableaccount'] = "Activer le compte";
$messages['enddate'] = "Date de fin";
$messages['entriesfound'] = "entrées trouvées";
$messages['entryfound'] = "entrée trouvée";
$messages['eventfound'] = "événement trouvé";
$messages['eventsfound'] = "événements trouvés";
$messages['expiredaccounts'] = "Mots de passe expirés";
$messages['false'] = "Non";
$messages['forbiddenchars'] = "Votre mot de passe contient des caractères interdits";
$messages['forbiddenldapfields'] = "Votre mot de passe contient des valeurs de votre entrée LDAP";
$messages['forbiddenwords'] = "Votre mot de passe contient des mots interdits";
$messages['forcereset'] = "Forcer la réinitialisation à la prochaine connexion";
$messages['hookerror'] = "Une erreur s'est produite dans le hook";
$messages['idleaccounts'] = "Comptes inactifs";
$messages['idleaccountstitle'] = "Comptes inactifs depuis plus de $idledays jours";
$messages['insert_comment'] = "Insérer un commentaire";
$messages['insufficiententropy'] = "Entropie insuffisante pour le nouveau mot de passe";
$messages['invalidaccounts'] = "Comptes invalides";
$messages['invalidaccountstitle'] = "Comptes invalides";
$messages['label_action'] = "Action";
$messages['label_authtimestamp'] = "Dernière authentification";
$messages['label_businesscategory'] = "Catégorie";
$messages['label_carlicense'] = "Permis de conduire";
$messages['label_comment'] = "Commentaire";
$messages["label_created"] = "Créé";
$messages['label_date'] = "Date";
$messages['label_description'] = "Description";
$messages['label_displayname'] = "Nom d'affichage";
$messages['label_done_by'] = "Fait par";
$messages['label_employeenumber'] = "Numéro d'employé";
$messages['label_employeetype'] = "Type d'employé";
$messages['label_endtime'] = "Fin de validité";
$messages['label_expirationdate'] = "Date d'expiration";
$messages['label_fax'] = "Télécopie";
$messages['label_firstname'] = "Prénom";
$messages['label_fullname'] = "Nom complet";
$messages['label_identifier'] = "Identifiant";
$messages['label_ip'] = "Adresse IP";
$messages['label_lastname'] = "Nom";
$messages['label_l'] = "Ville";
$messages['label_mail'] = "Courriel";
$messages['label_mailquota'] = "Quota messagerie";
$messages['label_manager'] = "Responsable";
$messages['label_mobile'] = "Portable";
$messages["label_modified"] = "Modifié";
$messages['label_organizationalunit'] = "Service";
$messages['label_organization'] = "Organisation";
$messages['label_pager'] = "Messagerie";
$messages['label_phone'] = "Téléphone";
$messages['label_postaladdress'] = "Adresse";
$messages['label_postalcode'] = "Code postal";
$messages['label_pwdaccountlockedtime'] = "Date de verrouillage";
$messages['label_pwdchangedtime'] = "Dernier changement de mot de passe";
$messages['label_pwdfailuretime'] = "Derniers échecs d'authentification";
$messages['label_pwdgraceusetime'] = "Dernières authentifications en grâce";
$messages['label_pwdhistory'] = "Historique des changements de mot de passe";
$messages['label_pwdlastsuccess'] = $messages['label_authtimestamp'];
$messages['label_pwdpolicysubentry'] = "Politique des mots de passe associée";
$messages['label_pwdreset'] = "Réinitialisation du mot de passe à la prochaine connexion";
$messages['label_result'] = "Résultat";
$messages['label_sambaPwdLastSet'] = "Dernier changement de mot de passe";
$messages['label_sambaPwdCanChange'] = "Date pour pouvoir changer de mot de passe";
$messages['label_sambaPwdMustChange'] = "Date du changement obligatoire de mot de passe";
$messages['label_sambaKickoffTime'] = "Date de déconnexion automatique";
$messages['label_secretary'] = "Secrétaire";
$messages['label_starttime'] = "Début de validité";
$messages['label_state'] = "État";
$messages['label_street'] = "Voie";
$messages['label_title'] = "Titre";
$messages['label_user_dn'] = "Utilisateur";
$messages['ldaperror'] = "Erreur de communication avec l'annuaire LDAP";
$messages['lockaccount'] = "Verrouiller le compte";
$messages['lockedaccounts'] = "Comptes verrouillés";
$messages['logout'] = "Déconnexion";
$messages['mindigit'] = "Votre mot de passe n'a pas assez de chiffres";
$messages['minlower'] = "Votre mot de passe n'a pas assez de minuscules";
$messages['minspecial'] = "Votre mot de passe n'a pas assez de caractères spéciaux";
$messages['minupper'] = "Votre mot de passe n'a pas assez de majuscules";
$messages['newpassword'] = "Nouveau mot de passe";
$messages['newvalue'] = "Nouvelle valeur";
$messages['noentriesfound'] = "Aucune entrée trouvée";
$messages['noeventsfound'] = "Aucun événement trouvé";
$messages['notcomplex'] = "Votre mot de passe n'a pas assez de classes de caractères différentes.";
$messages['notdefined'] = "Non renseigné";
$messages['oldvalue'] = "Ancienne valeur";
$messages['pager_all'] = "Tout";
$messages['passwordchanged'] = "Le mot de passe a été changé";
$messages['passwordexpired'] = "Le mot de passe est expiré";
$messages['passwordinhistory'] = "Mot de passe déjà dans l'historique";
$messages['passwordinvalid'] = "Mot de passe incorrect";
$messages['password'] = "Mot de passe";
$messages['passwordok'] = "Authentification réussie !";
$messages['passwordrefused'] = "Le mot de passe a été refusé";
$messages['passwordrequired'] = "Merci de saisir le mot de passe";
$messages['policycomplex'] = "Nombre minimum de classes de caractères :";
$messages['policydifflogin'] = "Votre nouveau mot de passe ne doit pas être identique à votre identifiant";
$messages['policydiffminchars'] = "Nombre de nouveaux caractères unique :";
$messages['policyentropy'] = "Force du mot de passe";
$messages['policyforbiddenchars'] = "Caractères interdits :";
$messages['policyforbiddenldapfields'] = "Votre mot de passe ne doit pas contenir la valeur des attributs de votre entrée :";
$messages['policyforbiddenwords'] = "Votre mot de passe ne doit pas contenir ::";
$messages['policymaxlength'] = "Nombre maximum de caractères :";
$messages['policymindigit'] = "Nombre minimum de chiffres :";
$messages['policyminlength'] = "Nombre minimum de caractères :";
$messages['policyminlower'] = "Nombre minimum de minuscules :";
$messages['policyminspecial'] = "Nombre minimum de caractères spéciaux :";
$messages['policyminupper'] = "Nombre minimum de majuscules :";
$messages['policynoreusecustompwdfield'] = "Votre nouveau mot de passe ne devrait pas être le même que le mot de passe de connexion";
$messages['policynoreuse'] = "Votre nouveau mot de passe ne doit pas être identique à l'ancien";
$messages['policypwned'] = "Votre nouveau mot de passe ne doit pas être connu d'une base publique de mots de passe compromis";
$messages['policyspecialatends'] = "Votre nouveau mot de passe ne doit pas avoir son seul caractère spécial en première ou dernière position.";
$messages['policy'] = "Votre mot de passe doit respecter les contraintes suivantes :";
$messages['print_all'] = "Imprimer tous les résultats";
$messages['print_page'] = "Imprimer cette page";
$messages['pwned'] = "Votre nouveau mot de passe est compromis, vous devriez le changer partout où vous l'utilisez";
$messages['refreshentry'] = "Rafraîchir";
$messages['renameentry'] = "Renommer";
$messages['renamefailed'] = "Le renommage a échoué";
$messages['renameok'] = "L'entrée a été renommée";
$messages['resetpassword'] = "Réinitialisation du mot de passe";
$messages['sambaaccountstatus'] = 'Statut samba du compte';
$messages['sameascustompwd'] = "Le nouveau mot de passe n'est pas unique par rapport aux autres champs de mots de passe personnalisés";
$messages['sameaslogin'] = "Votre mot de passe est identique à votre identifiant";
$messages['sameasold'] = "Votre mot de passe est identique au précédent";
$messages['search'] = "Rechercher";
$messages['searchrequired'] = "Veuillez saisir votre recherche";
$messages['sizelimit'] = "La limite de recherche a été atteinte, certaines entrées n'ont pas pu être affichées";
$messages['specialatends'] = "Votre nouveau mot de passe a son unique caractère spécial en première ou dernière position";
$messages['startdate'] = "Date de début";
$messages['submit'] = "Envoyer";
$messages['title'] = "Guichet de service";
$messages['title_search'] = "Résultats de la recherche :";
$messages['toobig'] = "Votre mot de passe est trop long";
$messages['tooltip_emailto'] = "Envoyer un email";
$messages['tooltip_phoneto'] = "Composer ce numéro";
$messages['tooshort'] = "Votre mot de passe est trop court";
$messages['true'] = "Oui";
$messages['unlockaccount'] = "Déverrouiller le compte";
$messages['unlockdate'] = "Date de déblocage automatique :";
$messages['updateentry'] = "Modifier l'entrée";
$messages['updatefailed'] = "La modification a échoué";
$messages['updateok'] = "L'entrée a été modifiée";
$messages['updatevaliditydates'] = "Modifier les dates de validité";
$messages['validitydatesnotupdated'] = "Erreur lors de la mise à jour des dates de validité";
$messages['validitydatesupdated'] = "Dates de validité mises à jour";
$messages['welcome'] = "Bienvenue sur le guichet de service LDAP Tool Box";
$messages['willexpireaccounts'] = "Mots de passe bientôt expirés";
$messages['willexpireaccountstitle'] = "Mots de passe allant expirer dans moins de $willexpiredays jours";

?>
